@@ -6,7 +6,7 @@ import pathlib  # Manipulation de chemins
 
 # Description de signatures de fonctions
 from typing import Union, Callable, Any
-from functools import partial  # Manipuler des fonctions
+from functools import partial, wraps  # Manipuler des fonctions
 from inspect import signature  # Utiliser les signatures de fonctions
 
 # Bibliothèques via PIPy
@@ -480,7 +480,7 @@ class BaseTableau:
         :rtype: NoneType
 
         """
-        self.table: str = table
+        self.nom_table: str = table
         self.index_col = index_col
 
         if isinstance(db, str):
@@ -513,9 +513,19 @@ class BaseTableau:
                     sig = signature(obj)
 
                     if len(sig.parameters) == 1 and 'table' in sig.parameters:
-                        résultat = partial(obj, self.table)()
+                        résultat = partial(obj, self.nom_table)()
                     elif 'table' in sig.parameters:
-                        résultat = partial(obj, self.table)
+                        partielle = partial(obj, self.nom_table)
+                        
+                        @wraps(partielle)
+                        def résultat(*args, **kargs):
+                            try:
+                                self.db.index_col, vieux_index_col = self.index_col, self.db.index_col
+                                res = partielle(*args, **kargs)
+                            finally:
+                                self.db.index_col = vieux_index_col
+                            
+                            return res
                     else:
                         résultat = obj
                 else:
@@ -535,22 +545,3 @@ class BaseTableau:
     def df(self) -> pd.DataFrame:
         """Le tableau comme pandas.DataFrame."""
         return self.select()
-
-    def append(self, values: Union[pd.Series, pd.DataFrame] = None):
-        """
-        Ajoute des valeurs au tableau.
-
-        :param values: Valeurs à ajouter, defaults to None
-        :type values: Union[pd.Series, pd.DataFrame], optional
-        :return: None
-        :rtype: NoneType
-
-        """
-        if values is None:
-            cols, idx = self.columns, [max(self.index, default=-1) + 1]
-            values = pd.DataFrame(None, columns=cols, index=[idx])
-        elif isinstance(values, pd.Series):
-            cols, idx = self.columns, [max(self.index, default=-1) + 1]
-            values = pd.DataFrame([values], index=[idx])
-
-        self.db.append(self.table, values)
